[tor-commits] [tor/master] control: Rename a function variable

teor at torproject.org teor at torproject.org
Sun Dec 1 07:54:29 UTC 2019


commit 7a69b3aebc2d1aebc6851ac742c20acb574f78ea
Author: teor <teor at torproject.org>
Date:   Fri Nov 29 10:53:32 2019 +1000

    control: Rename a function variable
    
    Cleanup after 31531.
---
 src/feature/control/control_events.c | 10 +++++-----
 src/feature/control/control_events.h |  2 +-
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/feature/control/control_events.h b/src/feature/control/control_events.h
index 3e9192fcc..833727a49 100644
--- a/src/feature/control/control_events.h
+++ b/src/feature/control/control_events.h
@@ -158,7 +158,7 @@ int control_event_server_error(const char *format, ...)
 
 int control_event_guard(const char *nickname, const char *digest,
                         const char *status);
-int control_event_conf_changed(const struct config_line_t *elements);
+int control_event_conf_changed(const struct config_line_t *changes);
 int control_event_buildtimeout_set(buildtimeout_set_event_t type,
                                    const char *args);
 int control_event_signal(uintptr_t signal);





More information about the tor-commits mailing list
diff --git a/src/feature/control/control_events.c b/src/feature/control/control_events.c
index 02e30f66d..fb3410b89 100644
--- a/src/feature/control/control_events.c
+++ b/src/feature/control/control_events.c
@@ -1771,19 +1771,19 @@ control_event_guard(const char *nickname, const char *digest,
 }
 
 /** Called when a configuration option changes. This is generally triggered
  * by SETCONF requests and RELOAD/SIGHUP signals. The <b>elements</b> is
  * a smartlist_t containing (key, value, ...) pairs in sequence.
- * <b>value</b> can be NULL. */
+ * <b>changes</b> can be NULL. */
 int
-control_event_conf_changed(const config_line_t *elements)
+control_event_conf_changed(const config_line_t *changes)
 {
   char *result;
   smartlist_t *lines;
-  if (!EVENT_IS_INTERESTING(EVENT_CONF_CHANGED) || !elements) {
+  if (!EVENT_IS_INTERESTING(EVENT_CONF_CHANGED) || !changes) {
     return 0;
   }
   lines = smartlist_new();
-  for (const config_line_t *line = elements; line; line = line->next) {
+  for (const config_line_t *line = changes; line; line = line->next) {
     if (line->value == NULL) {
       smartlist_add_asprintf(lines, "650-%s", line->key);
     } else {
@@ -1771,19 +1771,19 @@ control_event_guard(const char *nickname, const char *digest,
 
 /** Called when a configuration option changes. This is generally triggered
- * by SETCONF requests and RELOAD/SIGHUP signals. The <b>elements</b> is
+ * by SETCONF requests and RELOAD/SIGHUP signals. The <b>changes</b> are
  * a smartlist_t containing (key, value, ...) pairs in sequence.